==> kerby-all-2.0.3-source-release.zip: kerby-all-2.0.3/kerby-kerb/kerb-kdc-test/src/test/java/org/apache/kerby/kerberos/kerb/server/RepeatLoginWithNettyKdcNetworkTest.java <==
/**
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */
package org.apache.kerby.kerberos.kerb.server;

import org.apache.kerby.kerberos.kdc.impl.NettyKdcServerImpl;
import org.apache.kerby.kerberos.kerb.KrbException;
import org.junit.Test;

public class RepeatLoginWithNettyKdcNetworkTest extends LoginTestBase {
    @Override
    protected void prepareKdc() throws KrbException {
        getKdcServer().setInnerKdcImpl(
            new NettyKdcServerImpl(getKdcServer().getKdcSetting()));
        super.prepareKdc();
    }

    @Test
    public void testLogin() throws Exception {
        checkSubject(super.loginServiceUsingKeytab());
    }

    @Test
    public void testLoginSecondTime() throws Exception {
        checkSubject(super.loginServiceUsingKeytab());
    }
}

==> kerby-all-2.1.1-source-release.zip: kerby-all-2.1.1/kerby-kerb/kerb-kdc-test/src/test/java/org/apache/kerby/kerberos/kerb/server/RepeatLoginWithNettyKdcNetworkTest.java <==
/**
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */
package org.apache.kerby.kerberos.kerb.server;

import org.apache.kerby.kerberos.kdc.impl.NettyKdcServerImpl;
import org.apache.kerby.kerberos.kerb.KrbException;
import org.junit.jupiter.api.Test;

public class RepeatLoginWithNettyKdcNetworkTest extends LoginTestBase {
    @Override
    protected void prepareKdc() throws KrbException {
        getKdcServer().setInnerKdcImpl(
            new NettyKdcServerImpl(getKdcServer().getKdcSetting()));
        super.prepareKdc();
    }

    @Test
    public void testLogin() throws Exception {
        checkSubject(super.loginServiceUsingKeytab());
    }

    @Test
    public void testLoginSecondTime() throws Exception {
        checkSubject(super.loginServiceUsingKeytab());
    }
}
